Module responsible for wrapping PES and PSI into TS packets.
Summary
Functions
Registeres new Program ID in the MPEG-TS packets stream.
Returns new instance of MPEG-TS packets serializer.
Serializes Packetized Elementry Stream.
Serializes Program Specific Information, like Program Association Tables or Program Mapping Table.
Types
Functions
@spec add_pid(t(), non_neg_integer()) :: t()
Registeres new Program ID in the MPEG-TS packets stream.
@spec new() :: t()
Returns new instance of MPEG-TS packets serializer.
Serializes Packetized Elementry Stream.
@spec serialize_psi(binary(), non_neg_integer(), t()) :: {[binary()], t()}
Serializes Program Specific Information, like Program Association Tables or Program Mapping Table.